@@ -1,6 +1,6 @@
 package Store::CouchDB;
 
-use Any::Moose;
+use Moose;
 use JSON;
 use LWP::UserAgent;
 use URI;
@@ -13,23 +13,16 @@ Store::CouchDB - a simple CouchDB driver
 
 =head1 VERSION
 
-Version 1.11.11.10.9.8.8
+VERSION 1.3
 
 =cut
 
 =head1 SYNOPSIS
 
-Store::CouchDB is a very thin wrapper around CouchDB. It is essentially
-a set of calls I use in production and is by no means a complete
-library, it is just complete enough for the things I need to do. This is
-a grown set of functions that evolved over the last years of using
-CouchDB in various projects and was written originally to be compatible
-with DB::CouchDB. This has long passed and can only be noticed at some
-places.
-
-One of the things I banged my head against for some time is non UTF8
-stuff that somehow enters the system and then breaks CouchDB. I use the
-brilliant Encoding::FixLatin module to fix this on the fly.
+Store::CouchDB is a very this wrapper around CouchDB. It is essentially
+a set of calls I use in production and that came in handy. This is not
+meant to be a complete library, it is just complete enough for the
+things i need to do.
 
     use Store::CouchDB;
 
@@ -43,20 +36,13 @@ brilliant Encoding::FixLatin module to fix this on the fly.
 
 =cut
 
-our $VERSION = '1.11';
+our $VERSION = '1.3';
 
 has 'debug' => (
     is        => 'rw',
+    required  => 1,
     default   => sub { },
-    lazy      => 1,
     predicate => 'is_debug',
-    clearer   => 'no_debug',
-);
-
-has 'url_encode' => (
-    is => 'rw',
-    isa => 'Bool',
-    default => 0
 );
 
 has 'host' => (
@@ -77,14 +63,6 @@ has 'db' => (
     default  => sub { '' }
 );
 
-has 'user' => (
-    is => 'rw',
-);
-
-has 'pass' => (
-    is => 'rw',
-);
-
 has 'method' => (
     is       => 'rw',
     required => 1,
@@ -123,14 +101,6 @@ The port to use. Defaults to '5984'
 
 The DB to use. This has to be set for all oprations!
 
-=head3 user
-
-The DB user to authenticate as. optional
-
-=head3 pass
-
-The password for the user to authenticate with. required if user is given.
-
 =head3 method
 
 This is internal and sets the request method to be used (GET|POST)
@@ -251,7 +221,6 @@ sub del_doc {
     $self->method('DELETE');
     $path = $self->db . '/' . $id . '?rev=' . $rev;
     my $res = $self->_call($path);
-    $self->method('GET');
     return $res->{rev} || undef;
 
 }
@@ -305,7 +274,7 @@ sub copy_doc {
     return $self->put_doc( { doc => $doc } );
 }
 
-=head2 get_view
+=head2
 
 There are several ways to represent the result of a view and various
 ways to query for a view. All the views support parameters but there are
@@ -337,14 +306,11 @@ sub get_view {
     my $c = 0;
     my $result;
     foreach my $doc ( @{ $res->{rows} } ) {
-        if($doc->{doc}){
-            $result->{ $doc->{key} || $c } = $doc->{doc};
-        } else {
         next unless $doc->{value};
-            # TODO debug why this crashes from time to time
-            #$doc->{value}->{id} = $doc->{id};
-            $result->{ $doc->{key} || $c } = $doc->{value};
-        }
+
+        # TODO debug why this crashes from time to time
+        #$doc->{value}->{id} = $doc->{id};
+        $result->{ $doc->{key} || $c } = $doc->{value};
         $c++;
     }
     return $result;
@@ -403,11 +369,6 @@ most and has the best support for corner cases.
        }
    );
 
-A normal response hash would be the "value" part of the document with
-the _id moved in as "id". If the response is not a HASH (the request was
-resulting in key/value pairs) the entire doc is returned resulting in a
-hash of key/value/id per document.
-
 =cut
 
 sub get_array_view {
@@ -424,12 +385,8 @@ sub get_array_view {
             push( @{$result}, $doc->{doc} );
         } else {
             next unless $doc->{value};
-            if(ref($doc->{value}) eq 'HASH'){
-                $doc->{value}->{id} = $doc->{id};
-                push( @{$result}, $doc->{value} );
-            } else {
-                push(@{$result}, $doc);
-            }
+            $doc->{value}->{id} = $doc->{id};
+            push( @{$result}, $doc->{value} );
         }
     }
     return $result;
@@ -529,9 +486,6 @@ sub _make_view_path {
     if ( $data->{opts} ) {
         my @opts;
         foreach my $opt ( keys %{ $data->{opts} } ) {
-            if($self->url_encode){
-                $data->{opts}->{$opt} =~ s/\+/%2B/g;
-            }
             push( @opts, $opt . '=' . $data->{opts}->{$opt} );
         }
         my $_opt = join( '&', @opts );
@@ -542,22 +496,16 @@ sub _make_view_path {
 
 sub _call {
     my ( $self, $path, $content ) = @_;
-    my $uri = 'http://';
-    $uri .= $self->user . ':' . $self->pass . '@'
-        if ($self->user and $self->pass);
-    $uri .= $self->host . ':' . $self->port . '/' . $path;
+    my $uri = 'http://' . $self->host . ':' . $self->port . '/' . $path;
     print STDERR "URI: $uri\n" if $self->is_debug;
 
     my $req = HTTP::Request->new();
     $req->method( $self->method );
     $req->uri($uri);
-
     $req->content( fix_latin( to_json($content, {allow_blessed => 1, convert_blessed => 1}), bytes_only => 1 ) )
       if ($content);
 
     my $ua  = LWP::UserAgent->new();
-    # FIXME set the content type to application/json
-    $ua->default_header('Content-Type' => "application/json");
     my $res = $ua->request($req);
     print STDERR "Result: " . $res->decoded_content . "\n" if $self->is_debug;
     if ( $res->is_success ) {
@@ -583,6 +531,9 @@ Please report any bugs or feature requests to C<bug-store-couchdb at rt.cpan.org
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Store-CouchDB>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -615,14 +566,14 @@ L<http://search.cpan.org/dist/Store-CouchDB/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks for DB::CouchDB which was very enspiring for writing this library
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Lenz Gschwendtner.
+Copyright 2009 Lenz Gschwendtner.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of either: the Apache License or the Artistic License.
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
